@@ -3,8 +3,8 @@ package config
 import (
 	"net/url"
 
-	"github.com/twstrike/coyim/Godeps/_workspace/src/golang.org/x/net/proxy"
-	ournet "github.com/twstrike/coyim/net"
+	ournet "github.com/coyim/coyim/net"
+	"golang.org/x/net/proxy"
 )
 
 func socks5UnixProxy(u *url.URL, d proxy.Dialer) (proxy.Dialer, error) {
@@ -24,7 +24,7 @@ func socks5UnixProxy(u *url.URL, d proxy.Dialer) (proxy.Dialer, error) {
 
 func genTorAutoString() string {
 	s := [10]byte{}
-	randomString(s[:])
+	_ = randomString(s[:])
 	return "randomTorAuto-" + string(s[:])
 }
 
@@ -50,9 +50,13 @@ func genTorAutoAuth(u *url.URL) *proxy.Auth {
 	return auth
 }
 
+var tornetAddress = func() string {
+	return ournet.Tor.Address()
+}
+
 func genTorAutoAddr(u *url.URL) string {
 	if u.Host == "" {
-		return ournet.Tor.Address()
+		return tornetAddress()
 	}
 
 	return u.Host
