@@ -1,6 +1,6 @@
 package gui
 
-import "github.com/twstrike/coyim/Godeps/_workspace/src/github.com/twstrike/gotk3adapter/gtki"
+import "github.com/coyim/gotk3adapter/gtki"
 
 func (u *gtkUI) showFirstAccountWindow() {
 	result := make(chan func())
@@ -13,16 +13,16 @@ func (u *gtkUI) showFirstAccountWindow() {
 		cleanup = dialog.Destroy
 
 		b.ConnectSignals(map[string]interface{}{
-			"on_import_signal": func() {
-				result <- u.runImporter
-			},
-			"on_register_signal": func() {
+			"on_register": func() {
 				result <- u.showServerSelectionWindow
 			},
-			"on_existing_signal": func() {
+			"on_existing": func() {
 				result <- u.showAddAccountWindow
 			},
-			"on_cancel_signal": func() {
+			"on_import": func() {
+				result <- u.runImporter
+			},
+			"on_cancel": func() {
 				result <- func() {}
 			},
 		})
