@@ -1,29 +1,42 @@
 package gui
 
 import (
+	"crypto/sha256"
 	"encoding/hex"
 	"io/ioutil"
-	"log"
 	"os"
 	"path/filepath"
 	"strings"
+	"sync"
 
-	"github.com/twstrike/coyim/Godeps/_workspace/src/github.com/twstrike/gotk3adapter/gdki"
+	"github.com/coyim/gotk3adapter/gdki"
+	log "github.com/sirupsen/logrus"
 )
 
-type icon struct {
-	encoded string
-	size    string
-	decoded []byte
-	cached  gdki.Pixbuf
-	path    string
-	name    string
+// Icon is a published interface that allows the conversion of an icon to a pixbuf
+type Icon interface {
+	GetPixbuf() gdki.Pixbuf
 }
 
+type icon struct {
+	encoded       string
+	size          string
+	width, height int
+	decoded       []byte
+	cached        gdki.Pixbuf
+	path          string
+	name          string
+}
+
+// CoyimIcon is the CoyIM official icon, as a 256x256 png
+var CoyimIcon Icon = coyimIcon
+
 var coyimIcon = &icon{
-	name: "coyimIcon_256x256.png",
-	path: "build/mac-bundle/coy.iconset/icon_256x256.png",
-	size: "256x256",
+	name:   "coyimIcon_256x256.png",
+	path:   "build/osx/mac-bundle/coyim.iconset/icon_256x256.png",
+	size:   "256x256",
+	width:  256,
+	height: 256,
 	encoded: "" +
 		"89504e470d0a1a0a0000000d49484452000001000000010008060000005c72a86600000004734249" +
 		"54080808087c08648800000009704859730000037600000376017dd582cc0000001974455874536f" +
@@ -230,8 +243,10 @@ var coyimIcon = &icon{
 }
 
 var statusIcons = map[string]*icon{
-	"unknown2": &icon{
-		size: "16x16",
+	"unknown2": {
+		size:   "16x16",
+		width:  16,
+		height: 16,
 		encoded: "" +
 			"89504E470D0A1A0A0000000D49484452000000100000001008060000001F" +
 			"F3FF61000000097048597300000B1300000B1301009A9C1800000A4F6943" +
@@ -343,8 +358,10 @@ var statusIcons = map[string]*icon{
 			"4D6DB0586F9D5DDFB4CAFF8B3F0300641EAD5DDBD40B2F0000000049454E" +
 			"44AE426082",
 	},
-	"busy": &icon{
-		size: "16x16",
+	"busy": {
+		size:   "16x16",
+		width:  16,
+		height: 16,
 		encoded: "" +
 			"" +
 			"89504e470d0a1a0a0000000d49484452000000100000001008060000001ff3ff6100000009704859" +
@@ -430,8 +447,10 @@ var statusIcons = map[string]*icon{
 			"3fcbb3e848bbf45d0000000049454e44ae426082",
 	},
 
-	"chat": &icon{
-		size: "16x16",
+	"chat": {
+		size:   "16x16",
+		width:  16,
+		height: 16,
 		encoded: "" +
 			"" +
 			"89504e470d0a1a0a0000000d49484452000000100000001008060000001ff3ff6100000009704859" +
@@ -518,8 +537,10 @@ var statusIcons = map[string]*icon{
 			"4e44ae426082",
 	},
 
-	"extended-away": &icon{
-		size: "16x16",
+	"extended-away": {
+		size:   "16x16",
+		width:  16,
+		height: 16,
 		encoded: "" +
 			"" +
 			"89504e470d0a1a0a0000000d49484452000000100000001008060000001ff3ff6100000009704859" +
@@ -605,8 +626,10 @@ var statusIcons = map[string]*icon{
 			"6b24c6eeecb86994ff177f0600b533a79d8fd40a510000000049454e44ae426082",
 	},
 
-	"invisible": &icon{
-		size: "16x16",
+	"invisible": {
+		size:   "16x16",
+		width:  16,
+		height: 16,
 		encoded: "" +
 			"" +
 			"89504e470d0a1a0a0000000d49484452000000100000001008060000001ff3ff6100000009704859" +
@@ -692,8 +715,10 @@ var statusIcons = map[string]*icon{
 			"b95fd29880cb2c140000000049454e44ae426082",
 	},
 
-	"offline": &icon{
-		size: "16x16",
+	"offline": {
+		size:   "16x16",
+		width:  16,
+		height: 16,
 		encoded: "" +
 			"" +
 			"89504e470d0a1a0a0000000d49484452000000100000001008060000001ff3ff6100000009704859" +
@@ -779,8 +804,10 @@ var statusIcons = map[string]*icon{
 			"b95fd29880cb2c140000000049454e44ae426082",
 	},
 
-	"unknown": &icon{
-		size: "16x16",
+	"unknown": {
+		size:   "16x16",
+		width:  16,
+		height: 16,
 		encoded: "" +
 			"89504e470d0a1a0a0000000d49484452000000100000000b080600000076e20d3900000004734249" +
 			"54080808087c0864880000000970485973000001060000010601cdd333bc0000001974455874536f" +
@@ -792,8 +819,10 @@ var statusIcons = map[string]*icon{
 			"426082",
 	},
 
-	"available": &icon{
-		size: "16x16",
+	"available": {
+		size:   "16x16",
+		width:  16,
+		height: 16,
 		encoded: "" +
 			"" +
 			"89504e470d0a1a0a0000000d49484452000000100000001008060000001ff3ff6100000009704859" +
@@ -880,8 +909,10 @@ var statusIcons = map[string]*icon{
 			"44ae426082",
 	},
 
-	"away": &icon{
-		size: "16x16",
+	"away": {
+		size:   "16x16",
+		width:  16,
+		height: 16,
 		encoded: "" +
 			"" +
 			"89504e470d0a1a0a0000000d49484452000000100000001008060000001ff3ff6100000009704859" +
@@ -967,8 +998,10 @@ var statusIcons = map[string]*icon{
 			"0c349fddfca80e948022f067bd22b55535ad591d1683a6ec60dd2affeffc1d005f1eb80123361f35" +
 			"0000000049454e44ae426082",
 	},
-	"connecting": &icon{ //animation
-		size: "16x16",
+	"connecting": { //animation
+		size:   "16x16",
+		width:  16,
+		height: 16,
 		encoded: "" +
 			"89504e470d0a1a0a0000000d49484452000000100000001008060000001ff3ff6100000009704859" +
 			"7300000b1300000b1301009a9c1800000a4f6943435050686f746f73686f70204943432070726f66" +
@@ -1054,11 +1087,70 @@ var statusIcons = map[string]*icon{
 	},
 }
 
-func (i *icon) get() []byte {
+func (i *icon) get() ([]byte, error) {
+	var err error
+
 	if i.decoded == nil {
-		i.decoded, _ = hex.DecodeString(i.encoded)
+		i.decoded, err = hex.DecodeString(i.encoded)
 	}
-	return i.decoded
+
+	return i.decoded, err
+}
+
+func (i *icon) GetPixbuf() gdki.Pixbuf {
+	var err error
+
+	if i.cached == nil {
+		i.cached, err = i.createPixBuf()
+		if err != nil {
+			panic(err)
+		}
+	}
+
+	return i.cached
+}
+
+func (i *icon) hash() string {
+	bytes, _ := i.get()
+	res := sha256.Sum256(bytes)
+	return hex.EncodeToString(res[:])
+}
+
+func (i *icon) createPixBufWithSize(width, height int) (gdki.Pixbuf, error) {
+	var w sync.WaitGroup
+	pl, err := g.gdk.PixbufLoaderNew()
+	if err != nil {
+		return nil, err
+	}
+
+	w.Add(1)
+	_ = pl.Connect("area-prepared", func() {
+		defer w.Done()
+	})
+
+	_ = pl.Connect("size-prepared", func() {
+		pl.SetSize(width, height)
+	})
+
+	bytes, err := i.get()
+	if err != nil {
+		return nil, err
+	}
+
+	if _, err := pl.Write(bytes); err != nil {
+		return nil, err
+	}
+
+	if err := pl.Close(); err != nil {
+		return nil, err
+	}
+
+	w.Wait() // should not use the buffer until the event has happened
+	return pl.GetPixbuf()
+}
+
+func (i *icon) createPixBuf() (gdki.Pixbuf, error) {
+	return i.createPixBufWithSize(i.width, i.height)
 }
 
 func getActualRootFolder() string {
@@ -1074,22 +1166,15 @@ func (i *icon) getPath() string {
 	if fileNotFound(iconPath) {
 		tmpIconPath := filepath.Join(filepath.Join(os.TempDir(), "coyim"), i.name)
 		if fileNotFound(tmpIconPath) {
-			os.MkdirAll(filepath.Join(os.TempDir(), "coyim"), 0755)
-			ioutil.WriteFile(tmpIconPath, i.get(), 0644)
-			log.Printf("gui/icons: wrote %s to %s\n", i.name, tmpIconPath)
+			_ = os.MkdirAll(filepath.Join(os.TempDir(), "coyim"), 0750)
+			bytes, _ := i.get()
+			_ = ioutil.WriteFile(tmpIconPath, bytes, 0600)
+			log.WithFields(log.Fields{
+				"name": i.name,
+				"path": tmpIconPath,
+			}).Debug("gui/icons: wrote file")
 		}
 		return tmpIconPath
 	}
 	return iconPath
 }
-
-func (i *icon) getPixbuf() gdki.Pixbuf {
-	if i.cached == nil {
-		pl, _ := g.gdk.PixbufLoaderNew()
-		pl.Write(i.get())
-		pl.Close()
-		pixbuf, _ := pl.GetPixbuf()
-		i.cached = pixbuf
-	}
-	return i.cached
-}
