@@ -1,6 +1,6 @@
 package gui
 
-import "github.com/twstrike/coyim/Godeps/_workspace/src/github.com/twstrike/gotk3adapter/gdki"
+import "github.com/coyim/gotk3adapter/gdki"
 
 // shift, control, super, hyper, meta,
 
@@ -12,11 +12,6 @@ func hasShift(evk gdki.EventKey) bool {
 	return hasState(evk, gdki.GDK_SHIFT_MASK)
 }
 
-// Used to indicate scroll lock or caps lock
-func hasLock(evk gdki.EventKey) bool {
-	return hasState(evk, gdki.GDK_LOCK_MASK)
-}
-
 func hasControl(evk gdki.EventKey) bool {
 	return hasState(evk, gdki.GDK_CONTROL_MASK)
 }
@@ -45,3 +40,33 @@ func hasEnter(evk gdki.EventKey) bool {
 	return evk.KeyVal() == gdki.KEY_Return ||
 		evk.KeyVal() == gdki.KEY_KP_Enter
 }
+
+func isShiftEnter(evk gdki.EventKey) bool {
+	return hasShift(evk) && hasEnter(evk)
+}
+
+func isNormalEnter(evk gdki.EventKey) bool {
+	return !hasControlingModifier(evk) && hasEnter(evk)
+}
+
+func isInsertEnter(evk gdki.EventKey, shiftEnterSends bool) bool {
+	if shiftEnterSends {
+		return isNormalEnter(evk)
+	}
+	return isShiftEnter(evk)
+}
+
+func isSend(evk gdki.EventKey, shiftEnterSends bool) bool {
+	if !shiftEnterSends {
+		return isNormalEnter(evk)
+	}
+	return isShiftEnter(evk)
+}
+
+func isTab(ev gdki.Event) bool {
+	return g.gdk.EventKeyFrom(ev).KeyVal() == gdki.KEY_Tab
+}
+
+func isLeftTab(ev gdki.Event) bool {
+	return g.gdk.EventKeyFrom(ev).KeyVal() == gdki.KEY_ISO_Left_Tab
+}
