@@ -1,8 +1,8 @@
 package gui
 
 import (
-	"github.com/twstrike/coyim/Godeps/_workspace/src/github.com/twstrike/gotk3adapter/gtki"
-	"github.com/twstrike/coyim/config"
+	"github.com/coyim/coyim/config"
+	"github.com/coyim/gotk3adapter/gtki"
 )
 
 type optionsMenu struct {
@@ -16,11 +16,14 @@ func (v *optionsMenu) setFromConfig(c *config.ApplicationConfig) {
 }
 
 func (u *gtkUI) toggleEncryptedConfig() {
-	if u.config != nil {
+	if u.config() != nil {
 		val := u.optionsMenu.encryptConfig.GetActive()
-		if u.config.SetShouldSaveFileEncrypted(val) {
+		if u.config().SetShouldSaveFileEncrypted(val) {
 			if val {
-				u.captureInitialMasterPassword(u.saveConfigOnly)
+				u.captureInitialMainPassword(u.saveConfigOnly, func() {
+					u.config().SetShouldSaveFileEncrypted(false)
+					u.saveConfigOnly()
+				})
 			} else {
 				u.saveConfigOnly()
 			}
