@@ -1,9 +1,9 @@
 package gui
 
 import (
-	"github.com/twstrike/coyim/Godeps/_workspace/src/github.com/twstrike/gotk3adapter/glib_mock"
-	"github.com/twstrike/coyim/Godeps/_workspace/src/github.com/twstrike/gotk3adapter/glibi"
-	. "github.com/twstrike/coyim/Godeps/_workspace/src/gopkg.in/check.v1"
+	"github.com/coyim/gotk3adapter/glib_mock"
+	"github.com/coyim/gotk3adapter/glibi"
+	. "gopkg.in/check.v1"
 )
 
 type SignalsSuite struct{}
@@ -24,8 +24,8 @@ func (*mockGlibSignalNew) SignalNew(v1 string) (glibi.Signal, error) {
 }
 
 func (*SignalsSuite) Test_initSignals_willInitTheSignals(c *C) {
-	g = Graphics{glib: &mockGlibSignalNew{}}
-	initSignals()
+	g := Graphics{glib: &mockGlibSignalNew{}}
+	initSignals(&inUIThread{g})
 	c.Assert(accountChangedSignal.(*mockSignal).name, Equals, "coyim-account-changed")
 	c.Assert(enableWindow.(*mockSignal).name, Equals, "enable")
 	c.Assert(disableWindow.(*mockSignal).name, Equals, "disable")
