@@ -2,12 +2,10 @@
 
 set -xe
 
-# Requires gccgo-X to be installed
-export GOROOT_BOOTSTRAP=/usr
+export GOROOT_BOOTSTRAP=/usr/lib/go-1.13
 
 cd /root/go
 source /root/setup-reproducible
 
 cd src
 ./make.bash
-
