@@ -1,9 +1,11 @@
 package interfaces
 
 import (
-	"github.com/twstrike/coyim/Godeps/_workspace/src/golang.org/x/net/proxy"
-	"github.com/twstrike/coyim/tls"
-	"github.com/twstrike/coyim/xmpp/data"
+	"github.com/coyim/coyim/coylog"
+	"github.com/coyim/coyim/servers"
+	"github.com/coyim/coyim/tls"
+	"github.com/coyim/coyim/xmpp/data"
+	"golang.org/x/net/proxy"
 )
 
 // Dialer connects and authenticates to an XMPP server
@@ -17,8 +19,13 @@ type Dialer interface {
 	SetJID(string)
 	SetPassword(string)
 	SetProxy(proxy.Dialer)
+	SetResource(string)
 	SetServerAddress(v string)
+	SetShouldConnectTLS(bool)
+	SetShouldSendALPN(bool)
+	SetLogger(coylog.Logger)
+	SetKnown(*servers.Server)
 }
 
 // DialerFactory represents a function that can create a Dialer
-type DialerFactory func(tls.Verifier) Dialer
+type DialerFactory func(tls.Verifier, tls.Factory) Dialer
